
=====
Open Badges Bakery
=====

This package contains the utilities needed to "bake" Open Badges metadata into PNG or SVG image files or extract ('unbake') metada from such images.

This Open Badges Bakery is produced by Concentric Sky. https://concentricsky.com

Some dependencies on Django remain, but the goal is to eliminate them and
present the bakery as a standalone python package with a command line
interface and python module API.

Usage and installation instructions coming.

